# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.network_edge_plugins_api import (
    NetworkEdgePluginsApi,
)  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestNetworkEdgePluginsApi(object):
    """NetworkEdgePluginsApi unit test stubs"""

    def test_delete_container(self):
        """Test case for delete_container

        """
        pass

    def test_delete_container_image(self):
        """Test case for delete_container_image

        """
        pass

    def test_get_container_logs(self):
        """Test case for get_container_logs

        """
        pass

    def test_get_container_system_i_ps(self):
        """Test case for get_container_system_i_ps

        """
        pass

    def test_get_container_system_images(self):
        """Test case for get_container_system_images

        """
        pass

    def test_get_container_system_running_containers(self):
        """Test case for get_container_system_running_containers

        """
        pass

    def test_get_container_system_status(self):
        """Test case for get_container_system_status

        """
        pass

    def test_post_action_container_system(self):
        """Test case for post_action_container_system

        """
        pass

    def test_post_commit_container(self):
        """Test case for post_commit_container

        """
        pass

    def test_post_create_container_image(self):
        """Test case for post_create_container_image

        """
        pass

    def test_post_start_container(self):
        """Test case for post_start_container

        """
        pass

    def test_put_configure_container_system(self):
        """Test case for put_configure_container_system

        """
        pass

    def test_put_edit_container_image(self):
        """Test case for put_edit_container_image

        """
        pass

    def test_put_stop_container(self):
        """Test case for put_stop_container

        """
        pass
